@@ -20,12 +20,13 @@
 #  DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
+
 from typing import Any, Iterator, List, Optional, TYPE_CHECKING, Tuple
 
 from .asset import Asset, AssetMixin
-from .utils import MISSING
 from .partial_emoji import _EmojiTag, PartialEmoji
 from .user import User
+from .utils import MISSING
 
 __all__ = (
     'Emoji',
@@ -107,18 +108,11 @@ class Emoji(_EmojiTag, AssetMixin):
         self._from_data(data)
 
     def _from_data(self, emoji: EmojiPayload):
-        self.require_colons: bool = emoji.get('require_colons', False)
-        self.managed: bool = emoji.get('managed', False)
         self.id: int = int(emoji['id'])  # type: ignore
-        self.name: str = emoji['name']  # type: ignore
-        self.animated: bool = emoji.get('animated', False)
-        self.available: bool = emoji.get('available', True)
-        self._roles: SnowflakeList = SnowflakeList(map(int, emoji.get('roles', [])))
-        user = emoji.get('user')
-        self.user: Optional[User] = User(state=self._state, data=user) if user else None
+        self.custom = True if emoji['type'] == 1 else False
 
     def _to_partial(self) -> PartialEmoji:
-        return PartialEmoji(name=self.name, animated=self.animated, id=self.id)
+        return PartialEmoji(id=self.id)
 
     def __iter__(self) -> Iterator[Tuple[str, Any]]:
         for attr in self.__slots__:
@@ -207,7 +201,8 @@ class Emoji(_EmojiTag, AssetMixin):
 
         await self._state.http.delete_custom_emoji(self.guild.id, self.id, reason=reason)
 
-    async def edit(self, *, name: str = MISSING, roles: List[Snowflake] = MISSING, reason: Optional[str] = None) -> Emoji:
+    async def edit(self, *, name: str = MISSING, roles: List[Snowflake] = MISSING,
+                   reason: Optional[str] = None) -> Emoji:
         r"""|coro|
 
         Edits the custom emoji.
