@@ -212,7 +212,7 @@ class MessageReference:
     -----------
     message_id: Optional[:class:`int`]
         引用的消息的 ID。
-    channel_id: :class:`int`
+    channel_id: Optional[:class:`int`]
         引用的消息的子频道 ID。
     guild_id: Optional[:class:`int`]
         所引用消息的频道 ID。
@@ -239,9 +239,6 @@ class MessageReference:
     def with_state(cls: Type[MR], state: ConnectionState, data: MessageReferencePayload) -> MR:
         self = cls.__new__(cls)
         self.message_id = data.get('message_id')
-        self.channel_id = int(data.pop('channel_id'))
-        self.guild_id = data.get('guild_id')
-        self.fail_if_not_exists = data.get('fail_if_not_exists', True)
         self._state = state
         self.resolved = None
         return self
@@ -283,9 +280,6 @@ class MessageReference:
 
     def to_dict(self) -> MessageReferencePayload:
         result: MessageReferencePayload = {'message_id': self.message_id} if self.message_id is not None else {}
-        result['channel_id'] = self.channel_id
-        if self.guild_id is not None:
-            result['guild_id'] = self.guild_id
         if self.fail_if_not_exists is not None:
             result['fail_if_not_exists'] = self.fail_if_not_exists
         return result
@@ -617,7 +611,7 @@ class Message(Hashable):
     def __repr__(self) -> str:
         name = self.__class__.__name__
         return (
-            f'<{name} id={self.id} channel={self.channel!r} type={self.type!r} author={self.author!r}>'
+            f'<{name} id={self.id} channel={self.channel!r} author={self.author!r}>'
         )
 
     def _try_patch(self, data, key, transform=None) -> None:
@@ -850,7 +844,7 @@ class Message(Hashable):
         it = filter(None, map(self.guild.get_channel, self.raw_channel_mentions))
         return utils._unique(it)
 
-    async def delete(self, *, delay: Optional[float] = None) -> None:
+    async def delete(self, *, delay: Optional[float] = None, hidetip: bool = False) -> None:
         """|coro|
         撤回消息。
 
@@ -858,6 +852,8 @@ class Message(Hashable):
         -----------
         delay: Optional[:class:`float`]
             如果提供，则在删除消息之前在后台等待的秒数。如果删除失败，则它会被静默忽略。
+        hidetip: bool
+            如果为 ``True`` ，将隐藏撤回灰条，默认为 ``False``
 
         Raises
         ------
@@ -879,7 +875,7 @@ class Message(Hashable):
 
             asyncio.create_task(delete(delay))
         else:
-            await self._state.http.delete_message(self.channel.id, self.id)
+            await self._state.http.delete_message(self.channel.id, self.id, hidetip)
 
     @property
     def edited_at(self) -> Optional[datetime.datetime]:
