@@ -21,8 +21,8 @@
 
 from __future__ import annotations
 
-from typing import Any, Dict, Optional, TYPE_CHECKING, Type, TypeVar, Union
 import re
+from typing import Any, Dict, Optional, TYPE_CHECKING, Type, TypeVar, Union, Tuple
 
 from .asset import AssetMixin
 from .error import InvalidArgument
@@ -33,7 +33,6 @@ __all__ = (
 
 if TYPE_CHECKING:
     from .state import ConnectionState
-    from datetime import datetime
     from .types.message import PartialEmoji as PartialEmojiPayload
 
 
@@ -79,29 +78,29 @@ class PartialEmoji(_EmojiTag, AssetMixin):
     -----------
     custom: :class:`bool`
         表情是否是 QQ 自定义表情。
-    id: :class:`str`
+    id: :class:`int`
         自定义表情符号的 ID（如果适用）。
     """
 
     __slots__ = ('animated', 'name', 'id', '_state', 'custom')
 
-    _CUSTOM_EMOJI_RE = re.compile(r'<?(?P<animated>a)?:?(?P<name>[A-Za-z0-9\_]+):(?P<id>[0-9]{13,20})>?')
+    _CUSTOM_EMOJI_RE = re.compile(r'<?emoji:(?P<id>[0-9]{13,20})>?')
 
     if TYPE_CHECKING:
-        id: Optional[str]
+        id: Optional[int]
 
     def __init__(self, *, custom: bool, id: str = None):
         self.custom = custom
-        self.animated = False
-        self.name = 'emoji'
-        self.id = id
+        self.id = int(id)
         self._state: Optional[ConnectionState] = None
+        if not custom:
+            self.name = chr(self.id)
 
     @classmethod
     def from_dict(cls: Type[PE], data: Union[PartialEmojiPayload, Dict[str, Any]]) -> PE:
         return cls(
-            id=data.get('id'),
-            custom=True if data.get('type') == 1 else 0,
+            id=int(data.get('id')),
+            custom=True if data.get('type') == 1 else False,
         )
 
     @classmethod
@@ -109,12 +108,10 @@ class PartialEmoji(_EmojiTag, AssetMixin):
         """将表情符号的 QQ 字符串表示形式转换为 :class:`PartialEmoji`。
         接受的格式是：
 
-        - ``a:name:id``
-        - ``<a:name:id>``
-        - ``name:id``
-        - ``<:name:id>``
+        - ``emoji:id``
+        - ``<emoji:id>``
 
-        如果格式不匹配，则假定它是一个 unicode 表情符号。
+        如果格式不匹配，则假定它是一个 unicode 表情符号，取第一个字符作为 emoji。
 
         Parameters
         ------------
@@ -130,8 +127,8 @@ class PartialEmoji(_EmojiTag, AssetMixin):
         if match is not None:
             groups = match.groupdict()
             emoji_id = groups['id']
-            return cls(id=emoji_id, custom=True)
-
+            return cls(id=int(emoji_id), custom=True)
+        value = ord(value[0])
         return cls(id=value, custom=False)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -161,7 +158,7 @@ class PartialEmoji(_EmojiTag, AssetMixin):
 
     def __eq__(self, other: Any) -> bool:
         if self.is_unicode_emoji():
-            return isinstance(other, PartialEmoji) and self.name == other.name
+            return isinstance(other, PartialEmoji) and self.id == other.id
 
         if isinstance(other, _EmojiTag):
             return self.id == other.id
@@ -181,13 +178,17 @@ class PartialEmoji(_EmojiTag, AssetMixin):
         """:class:`bool`: 检查这是否是 Unicode 表情符号。"""
         return not self.custom
 
-    def _as_reaction(self) -> str:
+    def _as_reaction(self) -> Tuple[bool, int]:
         if self.id is None:
             return self.name
-        return f'{self.name}:{self.id}'
+        return self.custom, self.id
 
     async def read(self) -> bytes:
         if self.is_unicode_emoji():
             raise InvalidArgument('PartialEmoji 不是自定义表情符号')
 
         return await super().read()
+
+    @property
+    def to_string(self):
+        return f'<emoji:{self.id}>' if self.custom else chr(self.id)
